"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.15.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.api.resources_api import ResourcesApi  # noqa: E501


class TestResourcesApi(unittest.TestCase):
    """ResourcesApi unit test stubs"""

    def setUp(self):
        self.api = ResourcesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_resource(self):
        """Test case for get_resource

        Get Resource  # noqa: E501
        """
        pass

    def test_list_resources(self):
        """Test case for list_resources

        List Resources  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
