"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.15.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.api.usage_and_billing_api import UsageAndBillingApi  # noqa: E501


class TestUsageAndBillingApi(unittest.TestCase):
    """UsageAndBillingApi unit test stubs"""

    def setUp(self):
        self.api = UsageAndBillingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_stripe_setup_intent(self):
        """Test case for create_stripe_setup_intent

        Create Stripe Setup Intent  # noqa: E501
        """
        pass

    def test_delete_payment_method(self):
        """Test case for delete_payment_method

        Delete Payment Method  # noqa: E501
        """
        pass

    def test_get_billing(self):
        """Test case for get_billing

        Get Billing  # noqa: E501
        """
        pass

    def test_list_usage(self):
        """Test case for list_usage

        List Usage  # noqa: E501
        """
        pass

    def test_update_billing(self):
        """Test case for update_billing

        Update Billing  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
