"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.15.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.api.records_api import RecordsApi  # noqa: E501


class TestRecordsApi(unittest.TestCase):
    """RecordsApi unit test stubs"""

    def setUp(self):
        self.api = RecordsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_record(self):
        """Test case for create_record

        Create Record  # noqa: E501
        """
        pass

    def test_list_actor_records(self):
        """Test case for list_actor_records

        List Actor Records  # noqa: E501
        """
        pass

    def test_list_records(self):
        """Test case for list_records

        List Records  # noqa: E501
        """
        pass

    def test_list_resource_records(self):
        """Test case for list_resource_records

        List Resource Records  # noqa: E501
        """
        pass

    def test_list_trail_records(self):
        """Test case for list_trail_records

        List Trail Records  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
